@@ -60,7 +60,8 @@ class EsRequest:
             json=body,
             headers={'content-type': "application/json"},
             params=params,
-            auth=self.auth
+            auth=self.auth,
+            timeout=None
         )
         res = r.json()
         return res
@@ -82,7 +83,8 @@ class EsRequest:
             params=params,
             json=body,
             headers={'content-type': "application/json"},
-            auth=self.auth
+            auth=self.auth,
+            timeout=None
         )
         res = r.json()
         return res
@@ -102,7 +104,8 @@ class EsRequest:
             url,
             params=params,
             headers={'content-type': "application/json"},
-            auth=self.auth
+            auth=self.auth,
+            timeout=None
         )
         res = r.json()
         return res
@@ -122,7 +125,8 @@ class EsRequest:
             url,
             params=params,
             headers={'content-type': "application/json"},
-            auth=self.auth
+            auth=self.auth,
+            timeout=None
         )
         res = r.json()
         return res
