@@ -1,8 +1,7 @@
 import functools
 import json
-import uuid
 
-import tornado.options
+from tornado.options import options
 
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.status_code import StatusCode
@@ -38,7 +37,7 @@ def user_verification(username="admin", **kw):
     def wrapper(func):
         @functools.wraps(func)
         def run(self, *args, **kwargs):
-            if tornado.options.options.running_env != "local":
+            if options.running_env != "local":
                 user_str = self.request.headers.get("User")
                 if user_str:
                     user = json.loads(user_str)
@@ -59,7 +58,7 @@ def user_verification(username="admin", **kw):
 
 
 def login_verification_func(self, *args, **kwargs):
-    if tornado.options.options.running_env != "local":
+    if options.running_env != "local":
         user = self.request.headers.get("User")
         if not user:
             raise BusinessException(StatusCode.INVALID_TOKEN)
@@ -72,9 +71,9 @@ def login_verification_func(self, *args, **kwargs):
 def login_verification(func):
     @functools.wraps(func)
     def wrapper(self, *args, **kwargs):
-        if not tornado.options.options.login_verification_func:
-            tornado.options.options.login_verification_func = login_verification_func
-        tornado.options.options.login_verification_func(self, *args, **kwargs)
+        if not options.login_verification_func:
+            options.login_verification_func = login_verification_func
+        options.login_verification_func(self, *args, **kwargs)
 
         return func(self, *args, **kwargs)
 
